@@ -1,9 +1,11 @@
+from __future__ import unicode_literals
+
 import base64
 import hashlib
 
 from django.core.urlresolvers import reverse
 
-from allaccess.compat import get_user_model
+from allaccess.compat import get_user_model, smart_bytes, force_text
 from allaccess.views import OAuthRedirect, OAuthCallback
 
 
@@ -23,10 +25,10 @@ class CustomCallback(OAuthCallback):
         email = info.get('email', None)
         if email is None:
             # No email was given by the provider so create a fake one
-            digest = hashlib.sha1(str(access)).digest()
+            digest = hashlib.sha1(smart_bytes(access)).digest()
             # Base 64 encode to get below 30 characters
             # Removed padding characters
-            email = u'%s@example.com' % base64.urlsafe_b64encode(digest).replace('=', '')
+            email = '%s@example.com' % force_text(base64.urlsafe_b64encode(digest)).replace('=', '')
         User = get_user_model()
         kwargs = {
             'email': email,
