@@ -1,11 +1,6 @@
+from django.conf.urls import url, include, handler404, handler500
 from django.contrib import admin
 from django.http import HttpResponse, HttpResponseNotFound, HttpResponseServerError
-try:
-    # Django 1.4+
-    from django.conf.urls import patterns, url, include, handler404, handler500
-except ImportError: # pragma: no cover
-    # Django 1.3
-    from django.conf.urls.defaults import patterns, url, include, handler404, handler500
 
 
 admin.autodiscover()
@@ -34,10 +29,10 @@ def test_500(request):
     return HttpResponseServerError()
 
 
-urlpatterns = patterns('',
+urlpatterns = [
     url(r'^allaccess/', include('allaccess.urls')),
     url(r'^allaccess/', include('allaccess.tests.custom.urls')),
     url(r'^error/$', error),
     url(r'^login/$', login),
     url(r'^$', home),
-)
+]
